@@ -54,30 +54,31 @@ def validate(
     gpkg_path, table_definitions_path=None, validations_path=None, validations=""
 ):
     """Starts the geopackage validations."""
-    utils.check_gdal_installed()
     utils.check_gdal_version()
 
-    # Explicit import here
-    from geopackage_validator.utils import init_gdal
-
-    results = []
+    gdal_traces = []
 
     # Register GDAL error handler function
     def gdal_error_handler(err_class, err_num, error):
-        result = format_result(
-            validation_code="GDAL_ERROR",
-            validation_description="No unexpected GDAL errors must occur.",
-            level=ValidationLevel.UNKNOWN,
-            trace=[error.replace("\n", " ")],
-        )
-        results.append(result)
+        trace = error.replace("\n", " ")
+        gdal_traces.append(trace)
 
-    init_gdal(gdal_error_handler)
-
-    dataset = utils.open_dataset(gpkg_path)
+    dataset = utils.open_dataset(gpkg_path, gdal_error_handler)
+    if len(gdal_traces):
+        initial_gdal_traces = [gdal_traces.pop() for _ in range(len(gdal_traces))]
+        initial_gdal_errors = [
+            format_result(
+                validation_code="GDAL_ERROR",
+                validation_description="No unexpected GDAL errors must occur.",
+                level=ValidationLevel.UNKNOWN,
+                trace=initial_gdal_traces,
+            )
+        ]
+    else:
+        initial_gdal_errors = []
 
     if dataset is None:
-        return results, None, False
+        return initial_gdal_errors, None, False
 
     is_rq8_requested = table_definitions_path is not None
     table_definitions = (
@@ -87,14 +88,16 @@ def validate(
     validators = validators_to_use(validations, validations_path, is_rq8_requested)
 
     validation_results = []
-    success = True
+    success = not initial_gdal_errors
 
     for validator in validators:
+        validation_error = False
         try:
             result = validator(dataset, table_definitions=table_definitions).validate()
 
             if result is not None:
                 validation_results.append(result)
+                validation_error = True
                 success = success and validator.level == ValidationLevel.RECCOMENDATION
         except Exception:
             exc_type, exc_value, exc_traceback = sys.exc_info()
@@ -103,18 +106,33 @@ def validate(
                 for t in traceback.format_exception(exc_type, exc_value, exc_traceback)
             ]
             output = format_result(
-                validation_code="ERROR",
-                validation_description="No unexpected errors must occur.",
-                level=ValidationLevel.UNKNOWN,
+                validation_code=validator.validation_code,
+                validation_description=f"No unexpected errors must occur for: {validator.__doc__}",
+                level=validator.level,
                 trace=trace,
             )
-            validation_results.append([output])
+            validation_results.append(output)
+            validation_error = True
             success = False
+        current_gdal_traces = [gdal_traces.pop() for _ in range(len(gdal_traces))]
+        if current_gdal_traces:
+            success = False
+            if validation_error:
+                validation_results[-1]["locations"].extend(current_gdal_traces)
+            else:
+                output = format_result(
+                    validation_code=validator.validation_code,
+                    validation_description=f"No unexpected errors must occur for: {validator.__doc__}",
+                    level=validator.level,
+                    trace=current_gdal_traces,
+                )
+                validation_results.append(output)
 
-    # results has values when a gdal error is thrown:
-    success = success and not results
-
-    return results + validation_results, get_validation_codes(validators), success
+    return (
+        initial_gdal_errors + validation_results,
+        get_validation_codes(validators),
+        success,
+    )
 
 
 def get_validation_descriptions():
